package Bundle::Locale::CLDR::Everything;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Everything

=head1 CONTENTS

Bundle::Locale::CLDR::World 0.44.1

Locale::CLDR::Transformations 0.44.1


=cut

1;

